pub enum JsonOperator {
Arrow,
LongArrow,
HashArrow,
HashLongArrow,
Question,
QuestionOr,
QuestionAnd,
AtArrow,
ArrowAt,
AtQuestion,
AtAt,
HashMinus,
}Variants
Arrow
-> keeps the value as json
LongArrow
->> keeps the value as text or int.
HashArrow
#> Extracts JSON sub-object at the specified path
HashLongArrow
#>> Extracts JSON sub-object at the specified path as text
Question
? Checks whether text key exist as top-level key or array element.
QuestionOr
?| Checks whether any of the text keys exist as top-level keys or array elements.
QuestionAnd
?& Checks whether all of the text keys exist as top-level keys or array elements.
AtArrow
@> Checks whether left json contains the right json
ArrowAt
<@ Checks whether right json contains the left json
AtQuestion
@? Checks whether JSON path return any item for the specified JSON value
AtAt
@@ Returns the result of a JSON path predicate check for the specified JSON value.
HashMinus
#- Deletes the field or array element at the specified keypath.
Implementations
Sourceimpl JsonOperator
impl JsonOperator
pub fn to_func_name(&self) -> String