Enum databend_common_ast::ast::Window
source · pub enum Window {
WindowReference(WindowRef),
WindowSpec(WindowSpec),
}Variants
WindowReference(WindowRef)
WindowSpec(WindowSpec)
Implementations
sourceimpl Window
impl Window
sourcepub fn as_window_reference_mut(&mut self) -> Option<&mut WindowRef>
pub fn as_window_reference_mut(&mut self) -> Option<&mut WindowRef>
Optionally returns mutable references to the inner fields if this is a Window::WindowReference, otherwise None
sourcepub fn as_window_reference(&self) -> Option<&WindowRef>
pub fn as_window_reference(&self) -> Option<&WindowRef>
Optionally returns references to the inner fields if this is a Window::WindowReference, otherwise None
sourcepub fn into_window_reference(self) -> Result<WindowRef, Self>
pub fn into_window_reference(self) -> Result<WindowRef, Self>
Returns the inner fields if this is a Window::WindowReference, otherwise returns back the enum in the Err case of the result
sourcepub fn as_window_spec_mut(&mut self) -> Option<&mut WindowSpec>
pub fn as_window_spec_mut(&mut self) -> Option<&mut WindowSpec>
Optionally returns mutable references to the inner fields if this is a Window::WindowSpec, otherwise None
sourcepub fn as_window_spec(&self) -> Option<&WindowSpec>
pub fn as_window_spec(&self) -> Option<&WindowSpec>
Optionally returns references to the inner fields if this is a Window::WindowSpec, otherwise None
sourcepub fn into_window_spec(self) -> Result<WindowSpec, Self>
pub fn into_window_spec(self) -> Result<WindowSpec, Self>
Returns the inner fields if this is a Window::WindowSpec, otherwise returns back the enum in the Err case of the result