Module parser

Module parser 

Re-exports

pub use token::all_reserved_keywords;

Modules

dynamic_table
expr
query
script
statement
stream
token

Structs

Backtrace
Record the farthest position in the input before encountering an error.
Error
This error type accumulates errors and their position when backtracking through a parse tree. This take a deepest error at alt combinator.
Input
Input tokens slice with a backtrace that records all errors including the optional branch.

Enums

Dialect
ErrorKind
ErrorKind is the error type returned from parser.
ParseMode

Functions

display_parser_error
match_text
match_token
parse_cluster_key_exprs
parse_comma_separated_exprs
parse_comma_separated_idents
parse_database_ref
Parse a database reference string like “db” or “catalog.db”. Correctly handles quoted identifiers.
parse_expr
Parse udf function into Expr
parse_procedure_ref
Parse a procedure reference string like “my_proc(INT, STRING)” or “my_proc()”. Returns a ProcedureIdentity with the procedure name and argument types.
parse_raw_insert_stmt
parse_raw_replace_stmt
parse_sql
Parse a SQL string into Statements.
parse_table_ref
Parse a table reference string like “table”, “db.table”, or “catalog.db.table”. Correctly handles quoted identifiers like "my.weird.table".
parse_udf_ref
Parse a UDF name string (a single identifier). Rejects trailing tokens to avoid silently ignoring malformed input.
parse_values
run_parser
suggest_correction
Generate suggestion for SQL parsing error
tokenize_sql

Type Aliases

IResult