pub fn parse_udf_ref(sql: &str, dialect: Dialect) -> Result<Identifier>Expand description
Parse a UDF name string (a single identifier). Rejects trailing tokens to avoid silently ignoring malformed input.
pub fn parse_udf_ref(sql: &str, dialect: Dialect) -> Result<Identifier>Parse a UDF name string (a single identifier). Rejects trailing tokens to avoid silently ignoring malformed input.