Struct databend_common_ast::parser::Backtrace
source · pub struct Backtrace { /* private fields */ }Expand description
Record the farthest position in the input before encountering an error.
This is similar to the Error, but the information will not get lost
even the error is from a optional branch.
Implementations