Struct Error

pub struct Error<'a> {
    pub span: Range,
    pub errors: Vec<ErrorKind>,
    pub contexts: Vec<(Range, &'static str)>,
    pub backtrace: &'a Backtrace,
}
This error type accumulates errors and their position when backtracking through a parse tree. This take a deepest error at alt combinator.

Fields

span: Range

The span of the next token of the last valid one when encountering an error.

errors: Vec<ErrorKind>

List of errors tried in various branches that consumed the same (farthest) length of input.

contexts: Vec<(Range, &'static str)>

The backtrace stack of the error.

backtrace: &'a Backtrace

The extra backtrace of error in optional branches.

Implementations

Source

impl<'a> Error<'a>

pub fn from_error_kind(input: Input<'a>, kind: ErrorKind) -> Self