Re-exports
pub use token::all_reserved_keywords;
Modules
Structs
- Backtrace
- Record the farthest position in the input before encountering an error.
- Error
- This error type accumulates errors and their position when backtracking
through a parse tree. This take a deepest error at
altcombinator. - Input
- Input tokens slice with a backtrace that records all errors including the optional branch.
Enums
Functions
- display_
parser_ error - match_
text - match_
token - parse_
cluster_ key_ exprs - parse_
comma_ separated_ exprs - parse_
comma_ separated_ idents - parse_
database_ ref - Parse a database reference string like “db” or “catalog.db”. Correctly handles quoted identifiers.
- parse_
expr - Parse udf function into Expr
- parse_
procedure_ ref - Parse a procedure reference string like “my_proc(INT, STRING)” or “my_proc()”.
Returns a
ProcedureIdentitywith the procedure name and argument types. - parse_
raw_ insert_ stmt - parse_
raw_ replace_ stmt - parse_
sql - Parse a SQL string into
Statements. - parse_
table_ ref - Parse a table reference string like “table”, “db.table”, or “catalog.db.table”.
Correctly handles quoted identifiers like
"my.weird.table". - parse_
udf_ ref - Parse a UDF name string (a single identifier). Rejects trailing tokens to avoid silently ignoring malformed input.
- parse_
values - run_
parser - suggest_
correction - Generate suggestion for SQL parsing error
- tokenize_
sql