Module parser

Re-exports

pub use token::all_reserved_keywords;

Modules

dynamic_table
expr
query
script
statement
stream
token

Structs

Backtrace
Record the farthest position in the input before encountering an error.
Error
This error type accumulates errors and their position when backtracking through a parse tree. This take a deepest error at alt combinator.
Input
Input tokens slice with a backtrace that records all errors including the optional branch.

Enums

Dialect
ErrorKind
ErrorKind is the error type returned from parser.
ParseMode

Functions

display_parser_error
match_text
match_token
parse_comma_separated_exprs
parse_comma_separated_idents
parse_expr
Parse udf function into Expr
parse_raw_insert_stmt
parse_raw_replace_stmt
parse_sql
Parse a SQL string into Statements.
parse_values
run_parser
tokenize_sql

Type Aliases

IResult