Re-exports
pub use token::all_reserved_keywords;
Modules
Structs
- Backtrace
- Record the farthest position in the input before encountering an error.
- Error
- This error type accumulates errors and their position when backtracking
through a parse tree. This take a deepest error at
altcombinator. - Input
- Input tokens slice with a backtrace that records all errors including the optional branch.
Enums
Functions
- display_
parser_ error - match_
text - match_
token - parse_
comma_ separated_ exprs - parse_
comma_ separated_ idents - parse_
expr - Parse udf function into Expr
- parse_
raw_ insert_ stmt - parse_
raw_ replace_ stmt - parse_
sql - Parse a SQL string into
Statements. - parse_
values - run_
parser - tokenize_
sql