Module databend_common_ast::parser

source ·

Re-exports

Modules

Structs

  • Record the farthest position in the input before encountering an error.
  • This error type accumulates errors and their position when backtracking through a parse tree. This take a deepest error at alt combinator.
  • Input tokens slice with a backtrace that records all errors including the optional branch.

Enums

Functions

Type Aliases