Module databend_common_ast::parser
source · Re-exports
pub use token::all_reserved_keywords;
Modules
Structs
- Record the farthest position in the input before encountering an error.
- This error type accumulates errors and their position when backtracking through a parse tree. This take a deepest error at
altcombinator. - Input tokens slice with a backtrace that records all errors including the optional branch.
Enums
- ErrorKind is the error type returned from parser.
Functions
- Parse udf function into Expr
- Parse a SQL string into
Statements.